==> lightbox_tobii-1.0.1.tar.gz: lightbox_tobii/src/Form/LightboxTobiiSettingsForm.php <==
<?php

namespace Drupal\lightbox_tobii\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a form for modifying Lightbox Tobii global settings.
 */
class LightboxTobiiSettingsForm extends ConfigFormBase {

  /**
   * SettingsForm constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typedConfigManager
   *   The typed config service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    TypedConfigManagerInterface $typedConfigManager,
  ) {
    parent::__construct($config_factory, $typedConfigManager);
    $this->typedConfigManager = $typedConfigManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'lightbox_tobii_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'lightbox_tobii.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable('lightbox_tobii.settings');
    $config_schema = $this->typedConfigManager->getDefinition('lightbox_tobii.settings') + ['mapping' => []];
    $config_schema = $config_schema['mapping'];

    $form['zoom_text'] = [
      '#type' => 'textarea',
      '#title' => $config_schema['zoom_text']['label'],
      '#description' => $config_schema['zoom_text']['description'],
      '#default_value' => $config->get('zoom_text') ?? '',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable('lightbox_tobii.settings');
    $config->set('zoom_text', $form_state->getValue('zoom_text'));
    $config->save();
    // Confirmation on form submission.
    $this->messenger()->addMessage($this->t('The Lightbox Tobii settings have been saved.'));
  }

}

==> lightbox_tobii-1.2.0.tar.gz: lightbox_tobii/src/Form/LightboxTobiiSettingsForm.php <==
<?php

namespace Drupal\lightbox_tobii\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\lightbox_tobii\LightboxTobiiUtils;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a form for modifying Lightbox Tobii global settings.
 */
class LightboxTobiiSettingsForm extends ConfigFormBase {

  /**
   * SettingsForm constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typedConfigManager
   *   The typed config service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    TypedConfigManagerInterface $typedConfigManager,
  ) {
    parent::__construct($config_factory, $typedConfigManager);
    $this->typedConfigManager = $typedConfigManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'lightbox_tobii_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'lightbox_tobii.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable('lightbox_tobii.settings');
    $config_schema = $this->typedConfigManager->getDefinition('lightbox_tobii.settings') + ['mapping' => []];
    $config_schema = $config_schema['mapping'];

    $form['tobii_settings'] = [
      '#type' => 'textarea',
      '#title' => $config_schema['tobii_settings']['label'],
      '#default_value' => $config->get('tobii_settings'),
      '#description' => $config_schema['tobii_settings']['description'],
      '#rows' => 10,
      '#element_validate' => [[LightboxTobiiUtils::class, 'validateYamlSettings']],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable('lightbox_tobii.settings');
    $config->set('tobii_settings', $form_state->getValue('tobii_settings'));
    $config->save();
    // Confirmation on form submission.
    $this->messenger()->addMessage($this->t('The Lightbox Tobii default settings have been saved.'));
  }

}
